#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.1
visibility:           public
id:                   hasql-implicits-0.1.1-LjOSFhUHggn5bc0DTzay8c
key:                  hasql-implicits-0.1.1-LjOSFhUHggn5bc0DTzay8c
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  08c848fc75c7a0d8b1b7787a9d1d5ce4
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.1-LjOSFhUHggn5bc0DTzay8c
depends:
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.6.1.1-60ZE8JsN8ZP3ajxNPl6i3A
    network-ip-0.3.0.3-3rxstYalDwtHCkRSvDtFe7
    scientific-0.3.8.1-AT3R4FMwAbnHAVDYpRwOmQ text-2.0.2 time-1.12.2
    uuid-1.3.16.1-FtFpzG0ItEW5kni5q1Y0lR
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

